/* CommunicationController.m created by epeyton on Mon 08-Mar-1999 */

#import "ICQCommunicationController.h"
#include <netdb.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <sys/time.h>
#include <unistd.h>

#import "BuddyItem.h"
#import "NSStringAdditions.h"

#import "libc.h"

@implementation ICQCommunicationController

+ sharedInstance
{
    static id commController = nil;

    if (!commController) {
        commController = [[ICQCommunicationController alloc] init];
    }
    return commController;
}

- (id)init
{
    icq_Logged = f_icq_Logged;
    icq_Disconnected = f_icq_Disconnected;
    icq_RecvMessage = f_icq_RecvMessage;
    icq_RecvURL = f_icq_RecvURL;
    icq_RecvAdded = f_icq_RecvAdded;
    icq_RecvAuthReq = f_icq_RecvAuthReq;
    icq_UserFound = f_icq_UserFound;
    icq_SearchDone = f_icq_SearchDone;
    icq_UserOnline = f_icq_UserOnline;
    icq_UserOffline = f_icq_UserOffline;
    icq_UserStatusUpdate = f_icq_UserStatusUpdate;
    icq_InfoReply = f_icq_InfoReply;
    icq_ExtInfoReply = f_icq_ExtInfoReply;
    icq_Log = f_icq_Log;
    icq_SrvAck = f_icq_SrvAck;

    connected = NO;
    return [super init];
}

// for now do this to stop extra messages ...
- (void)initializeRunLoopCheck
{
    return;
}

- (void)executeRunLoopCheck:(NSTimer *)timer
{
    int r;
    fd_set fds;
    struct timeval tv;
    if (connected) {
        tv.tv_sec  = 0;
        tv.tv_usec = 0;
        FD_ZERO (&fds);
        FD_SET  (0, &fds);
        FD_SET  (sockServer, &fds);
        r=select(sockServer + 1, &fds, NULL, NULL, &tv);
        if(FD_ISSET(sockServer,&fds)){
            icq_Main();
        }


        if ([self commandToSend] == ICQ_SEND || [self commandToSend] == ICQ_SEND_AWAY) {
            icq_SendMessage([[[self nextUser] buddyName] intValue],(char *)[[self nextMessage] cString]);
            [self setCommandToSend:NO];
        }
    }
    // ICQ
    // processLoop();

}
    
- (void)sendIMToUser:(BuddyItem *)aBuddyItem message:(NSString *)message
{
    if (connected) {
        [self setNextUser:aBuddyItem];
        [self setNextMessage:[[NSMutableString stringWithString:message] stripHtmlFromString]];

        if ([[aBuddyItem service] isEqual:ICQ_SERVICE]) {
            [self setCommandToSend:ICQ_SEND];
        }
    }
    return;
}

- (void)sendAwayIMToUser:(BuddyItem *)aBuddyItem message:(NSString *)message
{
    if (connected) {

        [self setNextUser:aBuddyItem];
        [self setNextMessage:[[NSMutableString stringWithString:message] stripHtmlFromString]];

        if ([[aBuddyItem service] isEqual:ICQ_SERVICE]) {
            [self setCommandToSend:ICQ_SEND];
        }
    }
    return;
}

- (void)addBuddyItem:(BuddyItem *)aBuddyItem
{
    if (connected) {

        if ([[aBuddyItem service] isEqual:ICQ_SERVICE]) {
            icq_ContAddUser([[aBuddyItem buddyName] intValue]);
        }
    }
    return;
}

- (void)removeBuddyItem:(BuddyItem *)aBuddyItem
{
    if (connected) {

        if ([[aBuddyItem service] isEqual:ICQ_SERVICE]) {
            icq_ContDelUser([[aBuddyItem buddyName] intValue]);
        }
    }
    return;
}

- (void)shutdownServices
{
    if (connected) {
        connected = NO;
        icq_Logout();
    }
}

- (int)loginForUser:(NSString *)userName password:(NSString *)password
{
    sockServer=icq_Connect("icq.mirabilis.com",4000);

    icq_Init([userName intValue], [password cString]);
    icq_Login(STATUS_ONLINE);
    icq_HandleServerResponse();	
    send_icq_contacts();

    connected = YES;
    [self initializeICQTimer];
    return 1;
}

- (void)getUserInformationForBuddyItem:(BuddyItem *)aBuddyItem
{
    if (connected) {
        if ([[aBuddyItem service] isEqual:ICQ_SERVICE]) {
            icq_SendInfoReq((long)[[aBuddyItem buddyName] intValue]);
    	}
    }
    return;
}

- (void)getUserInformationForBuddyNamed:(NSString *)aBuddyName
{
    [self getUserInformationForBuddyItem:[BuddyItem buddyNamed:aBuddyName]];
    return;
}

- (void)getUserInformationForEmail:(NSString *)anEmailAddress
{
    if (connected) {
        icq_SendSearchReq([anEmailAddress cString], "", "", "");
    }
    return;
}

- (void)setProfile
{
    return;
}

- (void)setBlockedList
{	
    return;
}

- (void)setStatus:(int)status idleTime:(int)seconds
{
    if (connected) {

        switch(status) {

            case IDLE:
            case AWAY:
                icq_ChangeStatus(STATUS_AWAY);
                break;
            case BUSY:
                icq_ChangeStatus(STATUS_OCCUPIED);
                break;
            default:
                icq_ChangeStatus(STATUS_ONLINE);
                break;
        }
    }


    return;
}

- (void)initializeICQTimer
{
    connected = YES;
    [icqTimer invalidate];
    [icqTimer release];
    icqTimer = [[NSTimer scheduledTimerWithTimeInterval:ICQ_KEEP_ALIVE_TIME target:self selector:@selector(icqTimer:) userInfo:nil repeats:YES] retain];
}

- (void)icqTimer:sender
{
    if (connected) {
        icq_KeepAlive();
    }
}
        
		
@end
