/* MainController.h created by epeyton on Tue 16-Mar-1999 */

#import <AppKit/AppKit.h>

@class ChatWindow, CommunicationController, PreferencesController, ServiceController, BuddyController, ConsoleController;

@interface MainController : NSObject
{
    id 					communicationController;
    id					buddyController;
    id					serviceController;
    id					consoleController;
    id  				preferencesController;

    id 					choiceView;
    id					importView;

    id 					awayMenu;
    id					statusAwayMenu;

    NSMutableDictionary *registrationDict;
    NSMutableDictionary *configDict;

    NSString			*myScreenName;

    BOOL				loginCompleted;
    BOOL				inAwayState;
    NSString 			*currentAwayMessage;
    NSArray				*awayMessages;

    int 				writeType;
    int					readType;
    BOOL				mergeGroups;

    //NSStatusItem		*statusItem;
    id statusItem;
    NSMenu				*statusMenu;

    NSMutableDictionary *imagesForUsers;
    NSTimer				*idleTimer;
    BOOL				idle;

}

- (CommunicationController *)communicationController;
- (ServiceController *)serviceController;
- (ConsoleController *)consoleController;
- (BuddyController *)buddyController;
- (PreferencesController *)preferencesController;

- (NSDictionary *)configDict;

- (void)playSound:(NSString *)soundName;

- (NSString *)myScreenName;
- (void)setMyScreenName:(NSString *)aName;

- (void)newEmptyChatWindow:(id)sender;

- (void)chatWindowForUser:(NSString *)user withMessage:(NSString *)message isAutoReply:(BOOL)yn forService:(NSString *)serviceName;

- (void)registerChatWindow:(ChatWindow *)chatWindow;
- (void)unregisterChatWindow:(ChatWindow *)chatWindow;

- (void)completeLogin;

- (void)displayBuddyWindow:sender;
- (void)displayBuddySearch:sender;
- (void)displayPreferencesWindow:sender;
- (void)displayServiceWindow:sender;
- (void)displayAboutWindow:sender;
- (void)displayAwayWindow:sender;
- (void)displayAwayWindowForItem:sender;
- (void)displayConsoleWindow:sender;
- (void)throwFatalException;

- (void)buddySearch:sender;
- (void)displayUserInfoDictionary:(NSDictionary *)aDict;

- (NSFont *)boldListFont;
- (NSFont *)listFont;
- (NSFont *)italicListFont;

- (NSFont *)boldDisplayFont;
- (NSFont *)displayFont;

- (void)writeFireConfigWithGroups:(NSArray *)groupArray andBuddies:(NSArray *)buddyArray;

- (BOOL)loginCompleted;

- (BOOL)inAwayState;
- (void)setInAwayState:(BOOL)yn;

- (NSString *)currentAwayMessage;
- (void)setCurrentAwayMessage:(NSString *)awayMessage;

// import export
- (void)importBuddyList:(id)sender;
- (void)exportBuddyList:(id)sender;
- (void)writeUnixFile:(id)sender;
- (void)writeWindowsFile:(id)sender;
- (void)setMergeGroups:(id)sender;
- (void)importAliasList:(id)sender;
- (void)exportAliasList:(id)sender;

// opening links
- (void)performOpenURL:(NSString *)url;

// status bar icon
- (void)openMenuItemWindow:(id)sender;
- (NSMenu *)statusMenu;

// Image Handling
- (void)getImageIntoChatWindow:(ChatWindow *)cw;
- (BOOL)gettingImageForUser:(NSString *)userName;
- (void)setImageProfile:(NSString *)profString forUser:(NSString *)userName;
- (NSMutableDictionary *)imagesForUsers;

// Blocking Buddies
- (void)addToBlockedBuddyName:(NSString *)buddyName;
- (void)removeFromBlockedBuddyName:(NSString *)buddyName;
- (NSArray *)blockedBuddyNames;
- (BOOL)isBuddyNameBlocked:(NSString *)buddyName;

// Away Messaging
- (void)newAwayMessage:(id)sender;
- (void)setAwayMessage:(id)sender;
- (void)addToAwayMenusItemNamed:(NSString *)itemName;
- (void)removeFromAwayMenusItemNamed:(NSString *)itemName;

- (void)goIdle:(id)sender;
- (void)resetIdleTimer;
- (void)disableIdleTimer;

- (void)disconnectAllUsersWithService:(NSString *)service;

@end
